==> sitemodels-0.3.25.tgz: package/index.js <==
//
// Sitemodels - 1.1.2
//

var _ = require('./lib/help.js'),
    run = require('child_process'),
    fs = require('fs'),
    files = require('./lib/files.js'),
    collect = require('./lib/collect.js'),
    makecss = require('./lib/makecss.js'),
    interpret = require('./lib/interpret.js'),
    sort = require('./lib/sort.js'),
    assembleIndex = require('./lib/assembleIndex.js'),
    makeDocs = require('./lib/docs.js');

module.exports = (function() {

  return function(options) {


    var project_name = options.name || 'Insert Project Name Here',
        project_root = _.truePath(_.endSlash(options.root)) || null,
        project_sass = _.truePath(_.endSlash(options.sass)) || _.err('no sass source supplied'),
        project_js = _.truePath(_.endSlash(options.js)) || null,
        project_output = _.truePath(_.endSlash(options.output)) || _.err('no destination supplied'),
        project_structure = options.structure || null,
        project_notes = options.notes || null,
        js_dependencies = options.js_dependencies || null,
        css_output_style = options.css_output_style || 'nested';

    if (!fs.statSync(project_output).isDirectory()) _.err('project_output directory does not exist');


    var models = {}, data, globalCss, globalJs = '', sorted, docs, notes;


    // Get the files
    sassFiles = files.getSassFiles(project_sass);
    sassBuilds = files.getSassBuilds(project_sass);


    // Get the CSS
    if (sassBuilds.length < 1) {
      _.err('your project does not have any compilable sass output.');
    } else {
      globalCss = makecss(sassBuilds, css_output_style);
    }


    // Get the JS dependencies
    if (js_dependencies) {
      globalJs = '';
      js_dependencies.forEach(function(path) {
        globalJs += '// ' + project_js + path + '\n\n' + _.contents(project_js + path) + '\n\n';
      })
    }


    // Get the data
    if (sassFiles.length < 1) {
      _.err('your project does not include any sass files.');
    } else {
      sassFiles.forEach(function(file) {
        data = collect(file, models, globalCss);
      })
    }
    


    // Remove model CSS from globalCss
    // Include models with @global tag in globalCss
    _.find(globalCss, /(\/\*{3}[^]+?end-model\s*\*{3}\/)/g).forEach(function(comment) {
      var isGlobal = comment.match(/@global/);
      if (!isGlobal) {
        globalCss = globalCss.replace(comment, '');
      } else {
        var name = comment.match(/@name:\s*(.+)/)[1];
        var reformatted = comment.replace(/\/\*{3}[^]+?\*{3}\//g, '');
        reformatted = '/* model: ' + name + ' */' + reformatted;
        globalCss = globalCss.replace(comment, reformatted);
      }
    })


    // If a dir or file exists, do a thing; if not, do a different thing
    function ifExists(directory, success, fail) {
      var pass = true;
      try {
        fs.statSync(directory);
      } catch(e) {
        pass = false;
        if (fail) fail(directory, e);
      }
      if (pass && success) success(directory);
    }


    ifExists(project_output + 'data.json', function(file) {
      run.execSync('rm -r ' + file);
    })

    ifExists(project_output + 'index.html', function(file) {
      run.execSync('rm -r ' + file);
    })

    ifExists(project_output + 'global.css', function(file) {
      run.execSync('rm -r ' + file);
    })

    ifExists(project_output + 'js_dependencies.js', function(file) {
      run.execSync('rm -r ' + file);
    })


    // If models is present, remove and create
    ifExists(project_output + 'models', function(dir) {
      run.execSync('rm -r ' + dir);
      fs.mkdirSync(dir);
    }, function(dir, e) {
      fs.mkdirSync(dir);
    })


    // If js is present, remove and create
    ifExists(project_output + 'js', function(dir) {
      run.execSync('rm -r ' + dir);
      fs.mkdirSync(dir);
      fs.mkdirSync(dir + '/app');
    }, function(dir, e) {
      fs.mkdirSync(dir);
      fs.mkdirSync(dir + '/app');
    })

    ifExists(project_output + 'css', function(dir) {
      run.execSync('rm -r ' + dir);
      fs.mkdirSync(dir);
    }, function(dir, e) {
      fs.mkdirSync(dir);
    })

    ifExists(project_output + 'links', function(dir) {
      run.execSync('rm -r ' + dir);
      fs.mkdirSync(dir);
    }, function(dir, e) {
      fs.mkdirSync(dir);
    })
    

    // Interpret parsed model nodes
    data = interpret(models, project_output, project_js, project_root, project_sass);


    // Sort
    models = sort.create(project_structure);
    data = sort.collect(data, models);


    // Docs and Notes
    docs = makeDocs(__dirname + '/README.md');

    if (project_notes) {
      notes = makeDocs(project_notes);
    } else {
      notes = false;
    }


    // Get file contents
    var iFrameContent = _.contents(__dirname + '/assets/js/iframeContentWindow.min.js'),
        iFrameSizer = _.contents(__dirname + '/assets/js/iframeSizer.min.js'),
        appCss = _.contents(__dirname + '/assets/css/app.css'),
        prismCss = _.contents(__dirname + '/assets/css/prism.css'),
        appJs = _.contents(__dirname + '/assets/js/app.js'),
        jQuery = _.contents(__dirname + '/assets/js/jquery-3.1.1.min.js');


    // Write files
    // fs.writeFileSync(__dirname + '/tests/data.json', JSON.stringify(data, null, 2));
    fs.writeFileSync(project_output + 'css/app.css', appCss);
    fs.writeFileSync(project_output + 'css/prism.css', prismCss);
    fs.writeFileSync(project_output + 'css/global.css', globalCss.trim());
    fs.writeFileSync(project_output + 'js/app/app.js', appJs);
    fs.writeFileSync(project_output + 'js/app/jquery.js', jQuery);
    fs.writeFileSync(project_output + 'js/app/dependencies.js', globalJs.trim());
    fs.writeFileSync(project_output + 'js/app/iframeContent.js', iFrameContent);
    fs.writeFileSync(project_output + 'js/app/iframeSizer.js', iFrameSizer);

    var appHTML = _.contents(__dirname + '/templates/app.html');
    
    appHTML = appHTML.replace(/\{\{PROJECT_NAME\}\}/, project_name.trim());
    appHTML = appHTML.replace(/\{\{MODEL_INDEX\}\}/, assembleIndex(data));
    appHTML = appHTML.replace(/\{\{DATA\}\}/, JSON.stringify(data));
    appHTML = appHTML.replace(/\{\{DOCS\}\}/, JSON.stringify(docs));
    
    if (project_notes) {
      appHTML = appHTML.replace(/\{\{NOTES\}\}/, JSON.stringify(notes));
    } else {
      appHTML = appHTML.replace(/\{\{NOTES\}\}/, '');
    }

    fs.writeFileSync(project_output + '/index.html', appHTML);

  }

})();

==> sitemodels-0.3.31.tgz: package/index.js <==
//
// Sitemodels - 1.1.2
//

var _ = require('./lib/help.js'),
    run = require('child_process'),
    fs = require('fs'),
    files = require('./lib/files.js'),
    collect = require('./lib/collect.js'),
    makecss = require('./lib/makecss.js'),
    interpret = require('./lib/interpret.js'),
    sort = require('./lib/sort.js'),
    assembleIndex = require('./lib/assembleIndex.js'),
    makeDocs = require('./lib/docs.js'),
    getsassdoc = require('./lib/getsassdoc.js');

module.exports = (function() {

  return function(options) {


    var project_name = options.name || 'Insert Project Name Here',
        project_root = _.truePath(_.endSlash(options.root)) || null,
        project_sass = _.truePath(_.endSlash(options.sass)) || _.err('no sass source supplied'),
        project_js = _.truePath(_.endSlash(options.js)) || null,
        project_output = _.truePath(_.endSlash(options.output)) || _.err('no destination supplied'),
        project_structure = options.structure || null,
        project_notes = options.notes || null,
        js_dependencies = options.js_dependencies || null,
        css_output_style = options.css_output_style || 'nested',
        sassdoc_path = options.sassdoc || null;

    if (!fs.statSync(project_output).isDirectory()) _.err('project_output directory does not exist');


    var models = {}, data, globalCss, globalJs = '', sorted, docs, notes, sassDocs;


    // Get the files
    sassFiles = files.getSassFiles(project_sass);
    sassBuilds = files.getSassBuilds(project_sass);


    // Get the CSS
    if (sassBuilds.length < 1) {
      _.err('your project does not have any compilable sass output.');
    } else {
      globalCss = makecss(sassBuilds, css_output_style);
    }


    // Get the JS dependencies
    if (js_dependencies) {
      globalJs = '';
      js_dependencies.forEach(function(path) {
        globalJs += '// ' + project_js + path + '\n\n' + _.contents(project_js + path) + '\n\n';
      })
    }


    // Get the data
    if (sassFiles.length < 1) {
      _.err('your project does not include any sass files.');
    } else {
      sassFiles.forEach(function(file) {
        data = collect(file, models, globalCss);
      })
    }
    


    // Remove model CSS from globalCss
    // Include models with @global tag in globalCss
    _.find(globalCss, /(\/\*{3}[^]+?end-model\s*\*{3}\/)/g).forEach(function(comment) {
      var isGlobal = comment.match(/@global/);
      if (!isGlobal) {
        globalCss = globalCss.replace(comment, '');
      } else {
        var name = comment.match(/@name:\s*(.+)/)[1];
        var reformatted = comment.replace(/\/\*{3}[^]+?\*{3}\//g, '');
        reformatted = '/* model: ' + name + ' */' + reformatted;
        globalCss = globalCss.replace(comment, reformatted);
      }
    })


    // Get sassdoc content
    if (sassdoc_path) {
      sassDocs = getsassdoc(sassdoc_path);
    }


    // If a dir or file exists, do a thing; if not, do a different thing
    function ifExists(directory, success, fail) {
      var pass = true;
      try {
        fs.statSync(directory);
      } catch(e) {
        pass = false;
        if (fail) fail(directory, e);
      }
      if (pass && success) success(directory);
    }


    ifExists(project_output + 'data.json', function(file) {
      run.execSync('rm -r ' + file);
    })

    ifExists(project_output + 'index.html', function(file) {
      run.execSync('rm -r ' + file);
    })

    ifExists(project_output + 'global.css', function(file) {
      run.execSync('rm -r ' + file);
    })

    ifExists(project_output + 'js_dependencies.js', function(file) {
      run.execSync('rm -r ' + file);
    })


    // If models is present, remove and create
    ifExists(project_output + 'models', function(dir) {
      run.execSync('rm -r ' + dir);
      fs.mkdirSync(dir);
    }, function(dir, e) {
      fs.mkdirSync(dir);
    })


    // If js is present, remove and create
    ifExists(project_output + 'js', function(dir) {
      run.execSync('rm -r ' + dir);
      fs.mkdirSync(dir);
      fs.mkdirSync(dir + '/app');
    }, function(dir, e) {
      fs.mkdirSync(dir);
      fs.mkdirSync(dir + '/app');
    })

    ifExists(project_output + 'css', function(dir) {
      run.execSync('rm -r ' + dir);
      fs.mkdirSync(dir);
    }, function(dir, e) {
      fs.mkdirSync(dir);
    })

    ifExists(project_output + 'links', function(dir) {
      run.execSync('rm -r ' + dir);
      fs.mkdirSync(dir);
    }, function(dir, e) {
      fs.mkdirSync(dir);
    })
    

    // Interpret parsed model nodes
    data = interpret(models, project_output, project_js, project_root, project_sass);


    // Sort
    models = sort.create(project_structure);
    data = sort.collect(data, models);


    // Docs and Notes
    docs = makeDocs(__dirname + '/README.md');

    if (project_notes) {
      notes = makeDocs(project_notes);
    } else {
      notes = false;
    }


    // Get file contents
    var iFrameContent = _.contents(__dirname + '/assets/js/iframeContentWindow.min.js'),
        iFrameSizer = _.contents(__dirname + '/assets/js/iframeSizer.min.js'),
        appCss = _.contents(__dirname + '/assets/css/app.css'),
        prismCss = _.contents(__dirname + '/assets/css/prism.css'),
        appJs = _.contents(__dirname + '/assets/js/app.js'),
        jQuery = _.contents(__dirname + '/assets/js/jquery-3.1.1.min.js');


    // Write files
    // fs.writeFileSync(__dirname + '/tests/data.json', JSON.stringify(data, null, 2));
    fs.writeFileSync(project_output + 'css/app.css', appCss);
    fs.writeFileSync(project_output + 'css/prism.css', prismCss);
    fs.writeFileSync(project_output + 'css/global.css', globalCss.trim());
    fs.writeFileSync(project_output + 'js/app/app.js', appJs);
    fs.writeFileSync(project_output + 'js/app/jquery.js', jQuery);
    fs.writeFileSync(project_output + 'js/app/dependencies.js', globalJs.trim());
    fs.writeFileSync(project_output + 'js/app/iframeContent.js', iFrameContent);
    fs.writeFileSync(project_output + 'js/app/iframeSizer.js', iFrameSizer);

    var appHTML = _.contents(__dirname + '/templates/app.html');
    
    appHTML = appHTML.replace(/\{\{PROJECT_NAME\}\}/, project_name.trim());
    appHTML = appHTML.replace(/\{\{MODEL_INDEX\}\}/, assembleIndex(data));
    appHTML = appHTML.replace(/\{\{DATA\}\}/, JSON.stringify(data));
    appHTML = appHTML.replace(/\{\{DOCS\}\}/, JSON.stringify(docs));
    
    if (project_notes) {
      appHTML = appHTML.replace(/\{\{NOTES\}\}/, JSON.stringify(notes));
    } else {
      appHTML = appHTML.replace(/\{\{NOTES\}\}/, '');
    }

    if (sassdoc_path) {
      appHTML = appHTML.replace(/\{\{SASSDOCS\}\}/, sassDocs);
    } else {
      appHTML = appHTML.replace(/\{\{SASSDOCS\}\}/, '');
    }

    fs.writeFileSync(project_output + '/index.html', appHTML);

  }

})();
